@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013, PyInstaller Development Team.
+# Copyright (c) 2013-2016, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -8,11 +8,7 @@
 #-----------------------------------------------------------------------------
 
 
-hiddenimports = ['sip', 'PyQt4.QtGui', 'PyQt4._qt']
+from PyInstaller.utils.hooks import qt4_plugins_binaries
 
-from PyInstaller.hooks.hookutils import qt4_plugins_binaries
-
-
-def hook(mod):
-    mod.binaries.extend(qt4_plugins_binaries('phonon_backend'))
-    return mod
+binaries = qt4_plugins_binaries('phonon_backend')
+hiddenimports = ['sip', 'PyQt4.QtGui']
