@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013, PyInstaller Development Team.
+# Copyright (c) 2005-2016, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -8,27 +8,24 @@
 #-----------------------------------------------------------------------------
 
 
-from PyInstaller.hooks.hookutils import exec_statement
+from PyInstaller.utils.hooks import exec_statement, is_module_satisfies
 
 # include most common database bindings
 # some database bindings are detected and include some
 # are not. We should explicitly include database backends.
 hiddenimports = ['pysqlite2', 'MySQLdb', 'psycopg2']
 
-# sqlalchemy.databases package from pre 0.6 sqlachemy versions
-databases = exec_statement("import sqlalchemy.databases;print sqlalchemy.databases.__all__")
-databases = eval(databases.strip())
-
-for n in databases:
-    hiddenimports.append("sqlalchemy.databases." + n)
-
-# sqlalchemy.dialects package from 0.6 and newer sqlachemy versions
-version = exec_statement('import sqlalchemy; print sqlalchemy.__version__')
-is_alch06 = version >= '0.6'
-
-if is_alch06:
-    dialects = exec_statement("import sqlalchemy.dialects;print sqlalchemy.dialects.__all__")
+# In SQLAlchemy >= 0.6, the "sqlalchemy.dialects" package provides dialects.
+if is_module_satisfies('sqlalchemy >= 0.6'):
+    dialects = exec_statement("import sqlalchemy.dialects;print(sqlalchemy.dialects.__all__)")
     dialects = eval(dialects.strip())
 
-    for n in databases:
+    for n in dialects:
         hiddenimports.append("sqlalchemy.dialects." + n)
+# In SQLAlchemy <= 0.5, the "sqlalchemy.databases" package provides dialects.
+else:
+    databases = exec_statement("import sqlalchemy.databases; print(sqlalchemy.databases.__all__)")
+    databases = eval(databases.strip())
+
+    for n in databases:
+        hiddenimports.append("sqlalchemy.databases." + n)
